
CREATE TABLE CALL
  (
    ID                  NUMBER NOT NULL,
    REFERENCE           VARCHAR2(200 BYTE) NOT NULL,
    REPORTED_BY         VARCHAR2(12 BYTE) NOT NULL,
    DESCRIPTION         VARCHAR2(3500 BYTE) NOT NULL,
    TYPE                CHAR(1 BYTE) NOT NULL,
    CALL_RELATIONSHIP   VARCHAR2(12 BYTE) NOT NULL,
    IS_ACTIVE           CHAR(1 BYTE) DEFAULT 'Y' NOT NULL,
    PRODUCT             VARCHAR2(12 BYTE) NOT NULL,
    CLASSIFICATION      VARCHAR2(12 BYTE),
    CAUSE               VARCHAR2(2 BYTE),
    UPDATED             DATE,
    CREATED_AT          DATE DEFAULT sysdate,
    UPDATED_AT          DATE DEFAULT sysdate,
    CONSTRAINT PK_CALL PRIMARY KEY (ID)
  );

  CREATE OR REPLACE EDITIONABLE TRIGGER CALL_ID_TRG
BEFORE INSERT ON CALL
FOR EACH ROW
BEGIN
  <<COLUMN_SEQUENCES>>
  BEGIN
    IF INSERTING AND :NEW.ID IS NULL THEN
      SELECT CALL_ID_SEQ.NEXTVAL INTO :NEW.ID FROM SYS.DUAL;
    END IF;
  END COLUMN_SEQUENCES;
END;
/
ALTER TRIGGER CALL_ID_TRG ENABLE;



CREATE TABLE CALL_ATTACHMENT
  (
    ID                              NUMBER NOT NULL,
    CALL                            NUMBER NOT NULL,
    LABEL                           VARCHAR2(1000 BYTE),
    FILENAME                        VARCHAR2(1000 BYTE) NOT NULL,
    FILETYPE                        VARCHAR2(100 BYTE),
    FILESIZE                        NUMBER,
    CREATED_BY                      VARCHAR2(12 BYTE) NOT NULL,
    CREATED_AT                      DATE NOT NULL,
    CALL_RELATIONSHIP_ATTACHMENT    VARCHAR2(1000 BYTE),
    CONSTRAINT PK_CALL_ATTACHMENT PRIMARY KEY (ID)
  );

CREATE OR REPLACE EDITIONABLE TRIGGER CALL_ATTACHMENT_ID_TRG
BEFORE INSERT ON CALL_ATTACHMENT
FOR EACH ROW
BEGIN
  <<COLUMN_SEQUENCES>>
  BEGIN
    IF INSERTING AND :NEW.ID IS NULL THEN
      SELECT CALL_ATTACHMENT_ID_SEQ.NEXTVAL INTO :NEW.ID FROM SYS.DUAL;
    END IF;
  END COLUMN_SEQUENCES;
END;
/
ALTER TRIGGER CALL_ATTACHMENT_ID_TRG ENABLE;


CREATE TABLE CALL_COMMENT
  (
    ID            NUMBER NOT NULL,
    CALL          NUMBER NOT NULL,
    DESCRIPTION   VARCHAR2(2000 BYTE) NOT NULL,
    CREATED_BY    VARCHAR2(12 BYTE) NOT NULL,
    CREATED_AT    DATE NOT NULL,
    UPDATED_AT    DATE NOT NULL,
    CONSTRAINT CALL_COMMENT_PK PRIMARY KEY (ID)
  );

CREATE OR REPLACE EDITIONABLE TRIGGER CALL_COMMENT_ID_TRG
BEFORE INSERT ON CALL_COMMENT
FOR EACH ROW
BEGIN
  <<COLUMN_SEQUENCES>>
  BEGIN
    IF INSERTING AND :NEW.ID IS NULL THEN
      SELECT CALL_COMMENT_ID_SEQ.NEXTVAL INTO :NEW.ID FROM SYS.DUAL;
    END IF;
  END COLUMN_SEQUENCES;
END;
/
ALTER TRIGGER CALL_COMMENT_ID_TRG ENABLE;


CREATE TABLE CALL_LABEL
  (
    ID NUMBER NOT NULL,
    DESCRIPTION VARCHAR2(50 BYTE) NOT NULL,
    CREATED_BY VARCHAR2(12 BYTE) NOT NULL,
    UPDATED_BY VARCHAR2(12 BYTE),
    CREATED_AT DATE DEFAULT sysdate NOT NULL,
    UPDATED_AT DATE DEFAULT sysdate,
    CONSTRAINT CALL_LABEL_PK PRIMARY KEY (ID)
  );

CREATE OR REPLACE EDITIONABLE TRIGGER CALL_LABEL_ID_TRG
BEFORE INSERT ON CALL_LABEL
FOR EACH ROW
BEGIN
  <<COLUMN_SEQUENCES>>
  BEGIN
    IF INSERTING AND :NEW.ID IS NULL THEN
      SELECT CALL_LABEL_ID_SEQ.NEXTVAL INTO :NEW.ID FROM SYS.DUAL;
    END IF;
  END COLUMN_SEQUENCES;
END;
/
ALTER TRIGGER CALL_LABEL_ID_TRG ENABLE;



CREATE TABLE CALL_LABEL_RELATION
  (
    ID NUMBER NOT NULL,
    LABEL NUMBER NOT NULL,
    CALL NUMBER NOT NULL,
    CREATED_AT DATE DEFAULT sysdate,
    UPDATED_AT DATE DEFAULT sysdate,
    CREATED_BY VARCHAR2(12 BYTE) NOT NULL,
    UPDATED_BY VARCHAR2(12 BYTE) NOT NULL,
    CONSTRAINT CALL_LABEL_RELATION_PK PRIMARY KEY (ID)
  );

CREATE OR REPLACE EDITIONABLE TRIGGER CALL_LABEL_RELATION_ID_TRG
BEFORE INSERT ON CALL_LABEL_RELATION
FOR EACH ROW
BEGIN
  <<COLUMN_SEQUENCES>>
  BEGIN
    IF INSERTING AND :NEW.ID IS NULL THEN
      SELECT CALL_LABEL_RELATION_ID_SEQ.NEXTVAL INTO :NEW.ID FROM SYS.DUAL;
    END IF;
  END COLUMN_SEQUENCES;
END;
/
ALTER TRIGGER CALL_LABEL_RELATION_ID_TRG ENABLE;
